summaryrefslogtreecommitdiff
path: root/include/linux
diff options
context:
space:
mode:
Diffstat (limited to 'include/linux')
-rw-r--r--include/linux/fsverity.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/linux/fsverity.h b/include/linux/fsverity.h
index ea1ed2e6c2f9..ac5c98fd4602 100644
--- a/include/linux/fsverity.h
+++ b/include/linux/fsverity.h
@@ -114,9 +114,9 @@ struct fsverity_operations {
unsigned long num_ra_pages);
/**
* Write a Merkle tree block to the given inode.
*
* @inode: the inode for which the Merkle tree is being built
* @buf: the Merkle tree block to write
* @pos: the position of the block in the Merkle tree (in bytes)
* @size: the Merkle tree block size (in bytes)
@@ -126,7 +126,7 @@ struct fsverity_operations {
*
* Return: 0 on success, -errno on failure
*/
- int (*write_merkle_tree_block)(struct inode *inode, const void *buf,
+ int (*write_merkle_tree_block)(struct file *file, const void *buf,
u64 pos, unsigned int size);
};
@@ -114,9 +114,9 @@ struct fsverity_operations {
unsigned long num_ra_pages);
/**
- * Write a Merkle tree block to the given inode.
+ * Write a Merkle tree block to the given file.
*
@@ -114,9 +114,9 @@ struct fsverity_operations {
*
- * @inode: the inode for which the Merkle tree is being built
+ * @file: the file for which the Merkle tree is being built
* @buf: the Merkle tree block to write
* @pos: the position of the block in the Merkle tree (in bytes)